@@ -5,7 +5,7 @@
    $ Author: Mirko Boehm $
    $ Copyright: (C) 2005-2013 Mirko Boehm $
    $ Contact: mirko@kde.org
-         http://www.kde.org
+         https://www.kde.org
          http://creative-destruction.me $
 
    This library is free software; you can redistribute it and/or
@@ -25,7 +25,7 @@
 */
 
 #include <QString>
-#include <QtTest>
+#include <QTest>
 
 #include <ThreadWeaver/ThreadWeaver>
 #include <ThreadWeaver/JobPointer>
@@ -46,7 +46,7 @@ public:
         m_exists = false;
     }
 
-    void run(ThreadWeaver::JobPointer, ThreadWeaver::Thread *) {}
+    void run(ThreadWeaver::JobPointer, ThreadWeaver::Thread *) override {}
 
 private:
     bool &m_exists;
@@ -92,7 +92,7 @@ void LifecycleTests::testJobAutoDeletion()
         ThreadWeaver::JobPointer job1(new NotifyOnDeletejob(job1Exists));
         QCOMPARE(job1Exists, true);
         int argc = 0;
-        QCoreApplication app(argc, (char **)0); Q_UNUSED(app);
+        QCoreApplication app(argc, (char **)nullptr); Q_UNUSED(app);
         QVERIFY(ThreadWeaver::Queue::instance());
         ThreadWeaver::Queue::instance()->suspend();
         ThreadWeaver::Queue::instance()->enqueue(job1);
@@ -105,7 +105,7 @@ void LifecycleTests::testJobAutoDeletion()
         QCOMPARE(job2Exists, false);
         QCOMPARE(job1Exists, true);
     }
-    QVERIFY(ThreadWeaver::Queue::instance() == 0);
+    QVERIFY(ThreadWeaver::Queue::instance() == nullptr);
     QCOMPARE(job2Exists, false);
     QCOMPARE(job1Exists, false);
 }
