@@ -5,7 +5,7 @@ This file implements the Job class.
 $ Author: Mirko Boehm $
 $ Copyright: (C) 2004-2013 Mirko Boehm $
 $ Contact: mirko@kde.org
-http://www.kde.org
+https://www.kde.org
 http://creative-destruction.me $
 
    This library is free software; you can redistribute it and/or
@@ -29,8 +29,8 @@ $Id: Job.cpp 20 2005-08-08 21:02:51Z mirko $
 #include "job.h"
 #include "job_p.h"
 
-#include <QtCore/QList>
-#include <QtCore/QMutex>
+#include <QList>
+#include <QMutex>
 #include "debuggingaids.h"
 #include "thread.h"
 #include <QAtomicPointer>
