@@ -5,7 +5,7 @@
    $ Author: Mirko Boehm $
    $ Copyright: (C) 2005-2013 Mirko Boehm $
    $ Contact: mirko@kde.org
-         http://www.kde.org
+         https://www.kde.org
          http://creative-destruction.me $
 
    This library is free software; you can redistribute it and/or
@@ -43,7 +43,7 @@ public:
     {}
 
 protected:
-    void run(JobPointer, Thread *) Q_DECL_FINAL {
+    void run(JobPointer, Thread *) override {
         t();
     }
 
