@@ -5,7 +5,7 @@
    $ Author: Mirko Boehm $
    $ Copyright: (C) 2005-2013 Mirko Boehm $
    $ Contact: mirko@kde.org
-         http://www.kde.org
+         https://www.kde.org
          http://creative-destruction.me $
 
    This library is free software; you can redistribute it and/or
@@ -25,14 +25,20 @@
 
 */
 
-#include "queueapi_p.h"
+#include "queueapi.h"
 
 namespace ThreadWeaver
 {
 
-QueueAPI::QueueAPI(QObject *parent) :
-    QueueSignals(parent)
+QueueAPI::QueueAPI(QObject *parent)
+    : QueueSignals(parent)
 {
 }
 
+QueueAPI::QueueAPI(Private::QueueSignals_Private *d, QObject *parent)
+    : QueueSignals(d, parent)
+{
+
+}
+
 }
